bron_kerbosch_pivot

Function bron_kerbosch_pivot 

fn bron_kerbosch_pivot<G>(
    g: G,
    adj_mat: &G::AdjMatrix,
    r: HashSet<G::NodeId>,
    p: HashSet<G::NodeId>,
    x: HashSet<G::NodeId>,
) -> Vec<HashSet<G::NodeId>>
Finds maximal cliques containing all the vertices in r, some of the vertices in p, and none of the vertices in x.

By default, only works on undirected graphs. It can be used on directed graphs if the graph is symmetric. I.e., if an edge (u, v) exists, then (v, u) also exists.

Uses the Bron–Kerbosch algorithm with pivoting.